CatchBreadcrumb class

Constructors

CatchBreadcrumb({int? tsMs, required String type, String? category, String? message, CatchLevel? level, Map<String, dynamic>? data})

Properties

category String?
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
level CatchLevel?
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tsMs int
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited