PulseBranchingCondOp class

Constructors

PulseBranchingCondOp()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

answered → const String
contains → const String
equals → const String
gt → const String
gte → const String
inOp → const String
lt → const String
lte → const String
notAnswered → const String
notContains → const String
notEquals → const String
notInOp → const String