PulseTheme class

Constructors

PulseTheme({String? primaryColor, String? backgroundColor, String? foregroundColor, String? mutedColor, String? borderColor, String? fontFamily, String? darkMode, String? logoUrl})
const
PulseTheme.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor String?
final
borderColor String?
final
darkMode String?
final
fontFamily String?
final
foregroundColor String?
final
hashCode int
The hash code for this object.
no setterinherited
logoUrl String?
final
mutedColor String?
final
primaryColor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited