ItemReason enum
Reason an item resolved the way it did. Stable across server releases; unknown reasons fall into ItemReason.unknown.
Values
- archived → const ItemReason
- noRule → const ItemReason
- ruleMatched → const ItemReason
- notInRollout → const ItemReason
- inExcludedCohort → const ItemReason
- notInTargetCohort → const ItemReason
- cohortLookupFailed → const ItemReason
- countryBlocked → const ItemReason
- countryNotInAllow → const ItemReason
- countryUnknown → const ItemReason
- appVersionBelowMin → const ItemReason
- appVersionAboveMax → const ItemReason
- osVersionBelowMin → const ItemReason
- osVersionAboveMax → const ItemReason
- notInUserAllowList → const ItemReason
- unknown → const ItemReason
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ItemReason> - A constant List of the values in this enum, in order of their declaration.