PulseQuestion class
Constructors
-
PulseQuestion({required String id, required String kind, required String prompt, String? helptext, bool required = false, int orderIndex = 0, List<
PulseQuestionOption> ? options, Map<String, dynamic> ? validation}) -
const
-
PulseQuestion.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- helptext → String?
-
final
- id → String
-
final
- kind → String
-
final
-
options
→ List<
PulseQuestionOption> ? -
final
- orderIndex → int
-
final
- prompt → String
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validation
→ Map<
String, dynamic> ? -
Per-kind validation block; opaque map decoded lazily by the
renderer (e.g.
min/maxforslider,min_lengthfor text).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited