SankofaUpdateCheckResult class
Result of a checkForKbcUpdate call.
- Annotations
Constructors
- SankofaUpdateCheckResult({required SankofaUpdateStatus status, SankofaUpdate? update, String? reason})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUpdate → bool
-
Convenience getter — returns true when status is
outdated.no setter - reason → String?
-
Server-supplied reason string. Most useful when status is
SankofaUpdateStatus.unavailable or
SankofaUpdateStatus.invalidConfig. Examples:
"network_error:check:SocketException...","engine_unknown".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → SankofaUpdateStatus
-
Status. Drives the host's branching.
final
- update → SankofaUpdate?
-
The new patch, when status is SankofaUpdateStatus.outdated.
Null otherwise.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited